#!/bin/sh

VERSIONMOZ=1.7.6
VERSIONTRAD=1

pushd bin/chrome
./fait-jar.sh
popd

rm -f mozilla-l10n-fr-FR-$VERSIONMOZ-$VERSIONTRAD.xpi
zip -9 -D mozilla-l10n-fr-FR-$VERSIONMOZ-$VERSIONTRAD.xpi \
	install.js \
	`find bin/defaults -not -name 'mozilla-anglais.diff' |\
		grep -v CVS -` \
	`find bin/searchplugins -not -name 'mozilla-anglais.diff' |\
		grep -v CVS -` \
	`find bin/components -not -name 'mozilla-anglais.diff' |\
                grep -v CVS -` \
	bin/chrome/FR.jar \
	bin/chrome/fr-FR.jar \
	bin/chrome/fr-unix.jar \
	bin/chrome/fr-win.jar \
	bin/chrome/fr-mac.jar
